@@ -21,7 +21,7 @@
 // LAPACK++ was funded in part by the U.S. Department of Energy, the
 // National Science Foundation and the State of Tennessee.
 //
-// Modifications Copyright (C) 2000-2000 the R Development Core Team
+// Modifications Copyright (C) 2000-2001 the R Development Core Team
 
 #ifndef _LA_VECTOR_DOUBLE_H_
 #define _LA_VECTOR_DOUBLE_H_
@@ -32,6 +32,8 @@
 #include LA_GEN_MAT_DOUBLE_H
 #endif
 
+#include "laexcp.h"
+
 // a vector is simply an nx1 or 1xn, matrix, only that it can
 // be constructed and accessed by a single dimension
 
@@ -43,7 +45,7 @@ class LaVectorDouble: public LaGenMatDouble
     inline LaVectorDouble(int);
     inline LaVectorDouble(int, int);  
     inline LaVectorDouble(double*, int);
-    inline LaVectorDouble(double*, int, int);
+//    inline LaVectorDouble(double*, int, int);
     inline LaVectorDouble(const LaGenMatDouble&);
     inline explicit LaVectorDouble(SEXP);
     
@@ -53,6 +55,17 @@ class LaVectorDouble: public LaGenMatDouble
     inline int start() const;
     inline int end() const;
     
+    inline int size(int d) const
+        { if (d != 0) throw LaException("Vectors are one dimensional"); return size();}
+    inline int inc(int d) const
+        { if (d != 0) throw LaException("Vectors are one dimensional"); return inc();}
+    inline LaIndex index(int d) const
+        { if (d != 0) throw LaException("Vectors are one dimensional"); return index();}
+    inline int start(int d) const
+        { if (d != 0) throw LaException("Vectors are one dimensional"); return start();}
+    inline int end(int d) const
+        { if (d != 0) throw LaException("Vectors are one dimensional"); return end();}
+    
     inline LaVectorDouble& ref(const LaGenMatDouble &);
     LaVectorDouble& ref(SEXP);
     inline LaVectorDouble& inject(const LaMatDouble &);
@@ -60,10 +73,22 @@ class LaVectorDouble: public LaGenMatDouble
     inline LaVectorDouble* clone() const;
     LaVectorDouble& resize(int m)
 	{ LaGenMatDouble::resize(m, 1); return *this; };
+    LaVectorDouble& resize(int m, int n)
+        { if (m!= 1 || n != 1) throw LaException("Vectors are one dimensional"); resize(m*n); return *this; }
+    LaVectorDouble& resize(const LaVectorDouble &A)
+        { resize(A.size()); return *this; }
+    LaVectorDouble& resize(const LaMatDouble &A)
+        { resize(A.size(0)*A.size(1)); return *this; }
+
+    const double& operator()(int i, int j) const
+	{ return LaGenMatDouble::operator()(i,j); }
+    double& operator()(int i, int j)
+	{ return LaGenMatDouble::operator()(i,j); }
 
     inline double& operator()(int i);
     inline const double& operator()(int i) const ;
     inline LaVectorDouble operator()(const LaIndex&);
+    inline LaVectorDouble operator()(const LaIndex&) const;
     
     inline LaVectorDouble& operator=(double);
 
@@ -136,6 +161,13 @@ inline LaVectorDouble LaVectorDouble::operator()(const LaIndex& I)
     return LaGenMatDouble::operator()(I,LaIndex(0,0));
 }
 
+inline LaVectorDouble LaVectorDouble::operator()(const LaIndex& I) const
+{
+    if (LaGenMatDouble::size(0)==1)
+        return LaGenMatDouble::operator()(LaIndex(0,0),I);
+    return LaGenMatDouble::operator()(I,LaIndex(0,0));
+}
+
 inline LaVectorDouble& LaVectorDouble::copy(const LaMatDouble &A)
 {
 				//make sure rhs is a vector
